# Object Detection workflow in OpenCV (Only draws contours)

1. Start camera
    1. Open video capture
    2. if opened, mark as active
    3. fork new thread: grab frame, convert to image, update output
2. grab frame
    1. If camera is active, `capture.read(emptyFrame)`; assuming `emptyFrame` is no longer empty, continue
    2. Remove noise by running `blur(source,destination,kernelSize)`
    3. Convert from BGR to HSV, using `cvtColor`
    4. Create threshold based on HSV data specified below (Using the OpenCV `Scalar` type for both maximum and minimum)
    5. Threshold image using `inRange(hsvImage,minScalar,maxScalar,mask)`
    6. erode using small element (12x12 morphological rectangle)
    7. Dilate using large element (24x24 morphological rectangle)
    8. Find and draw image
3. find and draw object
    1. Find contours using `findContours(maskedImage, outputContours, heirarchy, mode, method)`
    2. For each contour, draw the contour on the frame
4. output image

Center of the contour can be found using the contour's moment (`moments(contours)`, centroid position is then found via m10/m00 for the X and m01/m00 for the Y)

for quick compilation, run Maven with the flag `-Djavacpp.platform=linux-x86_64`

# Context

HSV
- H: 0-360 degrees. Defines the hue of the pixel
- S: 0-100%. Defines the saturation of the pixel
- V: 0-100%. Defines the value (read: brightness) of the pixel

# Artisanal max/min pixel values

## Summary (Raw average)

OpenCV calculations are performed using 0-255 range rather than percentages, so the values below have been converted as necessary

- low
    - H: 118.92 deg
    - S:  18.87% (48/255)
    - V:  30.17% (77/255)
- high:
    - H:  50.53 deg
    - S:  15.71% (40/255)
    - V:  99.96% (255/255)

## `left5`

- low
    - H: 105.9
    - S:  21.8
    - V:  30.6
- high
    - H:  60.7
    - S:  32.5
    - V: 100.0

## `left6`

- low
    - H: 165.0
    - S:   8.7
    - V:  18.0
- high
    - H:  60.0
    - S:  24.7
    - V: 100.0

## `left7`

- low
    - H: 160.0
    - S:  19.4
    - V:  12.2
- high
    - H:  61.5
    - S:  15.7
    - V: 100.0

## `left8`

- low
    - H: 103.3
    - S:  18.4
    - V:  38.4
- high
    - H:  50.0
    - S:   2.4
    - V: 100.0

## `left9`

- low
    - H: 138.3
    - S:  25.0
    - V:  36.1
- high
    - H:  60.0
    - S:   0.8
    - V: 100.0

## `right5`

- low
    - H: 120.0
    - S:  15.8
    - V:  29.8
- high
    - H:  58.8
    - S:  19.3
    - V:  99.6

## `right6`

- low
    - H: 120.0
    - S:  11.1
    - V:  24.7
- high
    - H:  60.0
    - S:  17.3
    - V: 100.0

## `right7`

- low
    - H:  66.5
    - S:  31.6
    - V:  45.9
- high
    - H:  61.9
    - S:  12.2
    - V: 100.0

## `right8`

- low
    - H:  98.8
    - S:  20.2
    - V:  32.9
- high
    - H:  60.0
    - S:  15.7
    - V: 100.0

## `right9`

- low
    - H: 111.4
    - S:  16.9
    - V:  32.5
- high
    - H:  61.4
    - S:  16.5
    - V: 100.9
